@@ -461,7 +461,7 @@ def _upload_nginx_conf():
 
 def _reload_supervisorctl():
     sudo('%(supervisorctl)s reread' % env)
-    sudo('%(supervisorctl)s reload' % env)
+    # sudo('%(supervisorctl)s reload' % env)
 
 
 def _upload_supervisord_conf():
@@ -518,6 +518,14 @@ def _supervisor_restart():
         print green_bg("%s correctly started!" % env.supervisor_program_name)
 
 
+def _supervisor_reload():
+    with settings(hide('running', 'stdout', 'stderr', 'warnings'), warn_only=True):
+        res = sudo('%(supervisorctl)s reload %(supervisor_program_name)s' % env)
+    if 'ERROR' in res:
+        print red_bg("%s NOT RELOADED!" % env.supervisor_program_name)
+    else:
+        print green_bg("%s correctly reloaded!" % env.supervisor_program_name)
+
 def _read_key_file(key_file):
     key_file = expanduser(key_file)
     if not key_file.endswith('pub'):
